@@ -50,11 +50,11 @@ def inner_str(s: str, d: dict) -> str:
     return s
 
 
-def confirm_dummy():
+def confirm_dummy() -> None:
     ...
 
 
-def confirm_input():
+def confirm_input() -> None:
     input(">>> ")
 
 
@@ -72,10 +72,10 @@ class Sound:
     sound_filename: str
     confirm_f: Callable
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         self.sound_filename = get_real_sound_filename(self.sound_filename)
 
-    def run(self):
+    def run(self) -> vlc.MediaPlayer:
         p = vlc.MediaPlayer(self.sound_filename)
         p.play()
         return p
@@ -85,14 +85,13 @@ class Sound:
         return Sound(
             message=json["message"],
             sound_filename=json["sound_filename"],
-            # confirm_f=conv_confirm_f(json["confirm"])
-            confirm_f=confirm_dummy)
+            confirm_f=conv_confirm_f(json.get("confirm", "")))
 
     def __eq__(self, other) -> bool:
         return self.message == other.message and self.sound_filename == other.sound_filename
 
 
-def any_ended_sounds(ps):
+def any_ended_sounds(ps: List[vlc.MediaPlayer]) -> bool:
     for p in ps:
         if p.get_state() != vlc.State.Ended:
             return False
@@ -110,7 +109,7 @@ class ClockTimer:
     def sorted_sounds(self) -> Dict[int, Sound]:
         return {sec: self.sounds[sec] for sec in sorted(self.sounds)}
 
-    def run_once(self, count):
+    def run_once(self, count: int) -> None:
         sounds = self.sorted_sounds
 
         t = 0
@@ -126,8 +125,8 @@ class ClockTimer:
 
                     notification.send()
 
-                    sound.confirm_f()
                     ps.append(sound.run())
+                    sound.confirm_f()
 
             if len(sounds) == len(ps) and any_ended_sounds(ps):
                 break
@@ -138,9 +137,9 @@ class ClockTimer:
         while not any_ended_sounds(ps):
             time_sleep(1)
 
-    def run(self):
+    def run(self) -> None:
         count = 1
-        if type(self.loop) == int:
+        if isinstance(self.loop, int):
             for _ in range(self.loop):
                 self.run_once(count=count)
                 count += 1
@@ -150,7 +149,7 @@ class ClockTimer:
                 count += 1
 
     @classmethod
-    def from_dict(cls, json):
+    def from_dict(cls, json: dict) -> ClockTimer:
         sounds = {}
         for sec, sound in json["sounds"].items():
             sec = get_time_from_str(sec)
