@@ -28,17 +28,28 @@ def check_raw_clock(d) -> None:
     if type(d["sounds"]) != dict:
         raise ValueError("clock file err: sounds is not dict object.")
 
-    # sound["n"]はdict
-    # soundsのmessageは文字列型
-    # sounds_filenameがある
-    # sounds_filenameの値は文字列
-    # loopがなかったらエラー
-    # loopの値は0以上の整数
-    # titleがあるならば その値は文字列
+    if "loop" not in d:
+        raise ValueError("clock file err: doesn't include loop property.")
+
+    if type(d["loop"]) != int:
+        raise ValueError("clock file err: loop is not int object more than or equal to zero.")
+
+    if type(d.get("title", "")) != str:
+        raise ValueError("clock file err: title is not str object.")
 
     for time_s, sound in d["sounds"].items():
         if not is_time_str(time_s):
             raise ValueError(f"clock file err: {time_s} is not time.")
+        if type(sound) != dict:
+            raise ValueError(f"clock file err: sound at {time_s} is not dict object.")
+        if "message" not in sound:
+            raise ValueError(f"clock file err: message is not defined at {time_s}.")
+        if type(sound["message"]) != str:
+            raise ValueError(f"clock file err: message is not str object at {time_s}")
+        if "sound_filename" not in sound:
+            raise ValueError(f"clock file err: sound_filename is not defined at {time_s}.")
+        if type(sound["sound_filename"]) != str:
+            raise ValueError(f"clock file err: sound_filename is not str object at {time_s}")
 
         filename = get_real_sound_filename(sound["sound_filename"])
         if not Path(filename).exists():
@@ -52,7 +63,7 @@ def get_option_parser():
     return parser
 
 
-def main():
+def main() -> None:
     _, args = get_option_parser().parse_args()
 
     if len(args) != 1:
